@@ -8,7 +8,7 @@ use warnings;
 
 use Data::Unixish::Util qw(%common_args);
 
-our $VERSION = '1.51'; # VERSION
+our $VERSION = '1.52'; # VERSION
 
 our %SPEC;
 
@@ -37,11 +37,12 @@ sub pick {
         if (@picked < $n) {
             # we haven't reached n items, put item to picked list, in a random
             # position
-            splice @picked, rand(@picked), 0, $item;
+            splice @picked, rand(@picked+1), 0, $item;
         } else {
             # we have reached n items, just replace an item randomly, using
             # algorithm from Learning Perl, slightly modified.
-            rand($.) <= $n and $picked[rand(@picked)] = $item;
+            rand($index+1) < @picked and
+                splice @picked, rand(@picked), 1, $item;
         }
     }
 
@@ -64,7 +65,7 @@ Data::Unixish::pick - Pick one or more random items
 
 =head1 VERSION
 
-This document describes version 1.51 of Data::Unixish::pick (from Perl distribution Data-Unixish), released on 2015-10-07.
+This document describes version 1.52 of Data::Unixish::pick (from Perl distribution Data-Unixish), released on 2015-11-22.
 
 =head1 SYNOPSIS
 
@@ -124,7 +125,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixi
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Data-Unixish>.
+Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish>.
 
 =head1 BUGS
 
